/* Autogenerated by png2wx.pl on Thu Jul  3 20:05:20 2014 */
#ifndef ICONS_H
#define ICONS_H 1

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
#	include <wx/wx.h>
#endif

extern void initialize_images(void);

extern wxBitmap *_img_calc_fx;
extern wxBitmap *_img_calc;

#ifdef CALCULATOR_USE_SVG
extern wxString _svg_calculator;
extern wxString _svg_calculator_toggled;
#endif

#endif /* ICONS_H */
