

/* WARNING - DO NOT EDIT FILE - FILE IS AUTO GENERATED BY FUNCTIONS2CPP.PL*/

/***************************************************************************
 *
 * Project:  OpenCPN
 * Purpose:  ROUTE Plugin
 * Author:   SaltyPaws
 *
 ***************************************************************************
 *   Copyright (C) 2012 by Brazil BrokeTail                                *
 *   $EMAIL$                                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************
 */

#include "functions.h"

 CFormula::CFormula(void)
{
    this->Selected_Formula = 1;

this->m_ShortDesc.Add(_("Short_Description");
this->m_LongDesc.Add(_("Long_Description");
this->m_Category.Add(_("Category");
this->m_Source.Add(_("Source");
this->m_Formula.Add(_("Function");
this->m_Result_Unit.Add(_("Output_unit");
this->m_Input_parameter.Add(_("Input_param1");
this->m_Input_unit.Add(_("Input_unit1");
this->m_Input_parameter1.Add(_("Input_param2");
this->m_Input_unit1.Add(_("Input_unit2");
this->m_Input_parameter2.Add(_("Input_param2");
this->m_Input_unit2.Add(_("Input_unit2");
this->m_Input_parameter2.Add(_("Input_param3");
this->m_Input_unit2.Add(_("Input_unit3");
this->m_Input_parameter3.Add(_("Input_param3");
this->m_Input_unit3.Add(_("Input_unit3");
this->m_Input_parameter3.Add(_("Input_param4");
this->m_Input_unit3.Add(_("Input_unit4");
this->m_Input_parameter4.Add(_("Input_param4");
this->m_Input_unit4.Add(_("Input_unit4");
this->m_Input_parameter4.Add(_("Input_param5");
this->m_Input_unit4.Add(_("Input_unit5");
this->m_Input_parameter5.Add(_("Input_param5");
this->m_Input_unit5.Add(_("Input_unit5");
this->m_Input_parameter5.Add(_("Input_param6");
this->m_Input_unit5.Add(_("Input_unit6");
this->m_Input_parameter6.Add(_("Input_param6");
this->m_Input_unit6.Add(_("Input_unit6");
this->m_Input_parameter6.Add(_("Input_param7");
this->m_Input_unit6.Add(_("Input_unit7");
this->m_Input_parameter7.Add(_("Input_param7");
this->m_Input_unit7.Add(_("Input_unit7");
this->m_Input_parameter7.Add(_("Input_param8");
this->m_Input_unit7.Add(_("Input_unit8");
this->m_Input_parameter8.Add(_("Input_param8");
this->m_Input_unit8.Add(_("Input_unit8");
this->m_Input_parameter8.Add(_("Input_param9");
this->m_Input_unit8.Add(_("Input_unit9");
this->m_Input_parameter9.Add(_("Input_param9");
this->m_Input_unit9.Add(_("Input_unit9");
this->m_Input_parameter9.Add(_("Input_param10");
this->m_Input_unit9.Add(_("Input_unit10");

this->m_ShortDesc.Add(_("Hull Speed (imperial)");
this->m_LongDesc.Add(_("Hull speed, sometimes referred to as displacement speed, can be thought of the speed at which the wavelength of the boat's bow wave (in displacement mode) is equal to the boat length. As boat speed increases, the size of the bow wave increases, and therefore so does its wavelength. When hull speed is reached, a boat in pure displacement mode will appear trapped in a trough behind its very large bow wave.");
this->m_Category.Add(_("Design");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("vhull=1.34*sqrt(LWL)");
this->m_Result_Unit.Add(_("feet");
this->m_Input_parameter.Add(_("LWL");
this->m_Input_unit.Add(_("feet");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Hull Speed (metric)");
this->m_LongDesc.Add(_("Hull speed, sometimes referred to as displacement speed, can be thought of the speed at which the wavelength of the boat's bow wave (in displacement mode) is equal to the boat length. As boat speed increases, the size of the bow wave increases, and therefore so does its wavelength. When hull speed is reached, a boat in pure displacement mode will appear trapped in a trough behind its very large bow wave.");
this->m_Category.Add(_("Design");
this->m_Source.Add(_("Saltypaws");
this->m_Formula.Add(_("vhull=1.34*sqrt(LWL/0.3048)");
this->m_Result_Unit.Add(_("meter");
this->m_Input_parameter.Add(_("LWL");
this->m_Input_unit.Add(_("meter");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Draft of vessel when heeled");
this->m_LongDesc.Add(_("Draft of vessel when heeled");
this->m_Category.Add(_("Navigation");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("draft*cos(dtr*angle)");
this->m_Result_Unit.Add(_("As Input units draft");
this->m_Input_parameter.Add(_("angle");
this->m_Input_unit.Add(_("degree");
this->m_Input_parameter1.Add(_("draft");
this->m_Input_unit1.Add(_("As output units");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Speed of wind-driven current");
this->m_LongDesc.Add(_(" = 0.03 x (wind speed in kn)");
this->m_Category.Add(_("Navigation");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("Speed_Current = 0.03 * (Speed_Wind)");
this->m_Result_Unit.Add(_("knots");
this->m_Input_parameter.Add(_("Speed_Wind");
this->m_Input_unit.Add(_("knots");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Maximum Wavelength");
this->m_LongDesc.Add(_("Maximum Wavelength = 1.5 x square root of fetch in nm");
this->m_Category.Add(_("Navigation");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_(" Maximum_Wavelength = 1.5 * sqrt(fetch)");
this->m_Result_Unit.Add(_("???");
this->m_Input_parameter.Add(_("fetch");
this->m_Input_unit.Add(_("NM");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Wave speed =f(period)");
this->m_LongDesc.Add(_("Wave speed =  3.03 x (wave period in seconds)");
this->m_Category.Add(_("Navigation");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("Wave_speed =  3.03 * (wave_period)");
this->m_Result_Unit.Add(_("knots");
this->m_Input_parameter.Add(_("wave_period");
this->m_Input_unit.Add(_("seconds");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Change in height of Tide");
this->m_LongDesc.Add(_("Height is total change in tide hgt between high and low. The time ratio is time elapsed from the previous tide divided by the time difference between the two tides. \n\n\n\t(Similar to rule of 12 above)");
this->m_Category.Add(_("Navigation");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("Change_in_height_of_Tide:  =  height/2 * (1-cos(dtr(180) * time_ratio))");
this->m_Result_Unit.Add(_("As Input units height");
this->m_Input_parameter.Add(_("height");
this->m_Input_unit.Add(_("As Output units");
this->m_Input_parameter1.Add(_("time_ratio");
this->m_Input_unit1.Add(_("-");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("Flow rate of leak in boat");
this->m_LongDesc.Add(_("Flow rate of leak in boat:   Q = 3,600 (A) (H)\n                                Q = gallons per minute of water coming in\n                                A = area of hole in square feet\n                                H = height of water over hole in feet, to bottom of the opening");
this->m_Category.Add(_("Safety");
this->m_Source.Add(_("http://www.bootkeyharbor.com/Formulas.htm");
this->m_Formula.Add(_("Q = 3600 *(A)* (H)");
this->m_Result_Unit.Add(_("gallons per minute");
this->m_Input_parameter.Add(_("A");
this->m_Input_unit.Add(_("square feet");
this->m_Input_parameter1.Add(_("H");
this->m_Input_unit1.Add(_("feet");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");

this->m_ShortDesc.Add(_("hallo\nHallo1");
this->m_LongDesc.Add(_("");
this->m_Category.Add(_("");
this->m_Source.Add(_("");
this->m_Formula.Add(_("");
this->m_Result_Unit.Add(_("");
this->m_Input_parameter.Add(_("");
this->m_Input_unit.Add(_("");
this->m_Input_parameter1.Add(_("");
this->m_Input_unit1.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter2.Add(_("");
this->m_Input_unit2.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter3.Add(_("");
this->m_Input_unit3.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter4.Add(_("");
this->m_Input_unit4.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter5.Add(_("");
this->m_Input_unit5.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter6.Add(_("");
this->m_Input_unit6.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter7.Add(_("");
this->m_Input_unit7.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter8.Add(_("");
this->m_Input_unit8.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");
this->m_Input_parameter9.Add(_("");
this->m_Input_unit9.Add(_("");


}

