 /* WARNING - DO NOT EDIT FILE - FILE IS AUTO GENERATED BY FUNCTIONS2CPP.PL*/
  /***************************************************************************
  *
  * Project:  OpenCPN
  * Purpose:  ROUTE Plugin
  * Author:   SaltyPaws
  *
  ***************************************************************************
  *   Copyright (C) 2012 by Brazil BrokeTail                                *
  *   $EMAIL$                                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************
  */

 #ifndef _FUNCTIONS_H_
 #define _FUNCTIONS_H_
 #include "wx/wxprec.h"
 #ifndef  WX_PRECOMP
    #include "wx/wx.h"
 #endif //precompiled headers

class CFormula
{
	public:
	CFormula(void);				//Class constructor
         int Selected_Formula;                  // formula selected

		wxArrayString m_ShortDesc;					//Short_Description
		wxArrayString m_LongDesc;					//Long_Description
		wxArrayString m_Category;					//Category
		wxArrayString m_Source;					//Source
		wxArrayString m_Formula;					//Function
		wxArrayString m_Result_Unit;					//Output_unit
		wxArrayString m_Input_parameter;					//Input_param1
		wxArrayString m_Input_unit;					//Input_unit1
		wxArrayString m_Input_parameter1;					//Input_param2
		wxArrayString m_Input_unit1;					//Input_unit2
		wxArrayString m_Input_parameter2;					//Input_param3
		wxArrayString m_Input_unit2;					//Input_unit3
		wxArrayString m_Input_parameter3;					//Input_param4
		wxArrayString m_Input_unit3;					//Input_unit4
		wxArrayString m_Input_parameter4;					//Input_param5
		wxArrayString m_Input_unit4;					//Input_unit5
		wxArrayString m_Input_parameter5;					//Input_param6
		wxArrayString m_Input_unit5;					//Input_unit6
		wxArrayString m_Input_parameter6;					//Input_param7
		wxArrayString m_Input_unit6;					//Input_unit7
		wxArrayString m_Input_parameter7;					//Input_param8
		wxArrayString m_Input_unit7;					//Input_unit8
		wxArrayString m_Input_parameter8;					//Input_param9
		wxArrayString m_Input_unit8;					//Input_unit9
		wxArrayString m_Input_parameter9;					//Input_param10
		wxArrayString m_Input_unit9;					//Input_unit10
};
 #endif //_FUNCTIONS_H

